/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif // HAVE_CONFIG_H

#include "../bot.h"
#include "mod-follow-internal.h"

_mod_follow_context_t *
_mod_follow_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6bot_data_t * data)
{
  _mod_follow_context_t *follow_context = NULL;

  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("follow init"));

  follow_context = (_mod_follow_context_t *) LW6SYS_CALLOC (sys_context, sizeof (_mod_follow_context_t));
  if (follow_context)
    {
      // nothing to do, everything zeroed is fine
    }

  return follow_context;
}

void
_mod_follow_quit (lw6sys_context_t * sys_context, _mod_follow_context_t * follow_context)
{
  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("follow quit"));
  LW6SYS_FREE (sys_context, follow_context);
}
